/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codehaus.groovy.groovydoc;

import java.util.List;
import java.util.Map;

public interface GroovyRootDoc extends GroovyDoc, GroovyDocErrorReporter {
	GroovyClassDoc classNamed(String arg0);
	GroovyClassDoc[] classes();
	String[][] options();
	GroovyPackageDoc packageNamed(String arg0);
	GroovyClassDoc[] specifiedClasses();
	GroovyPackageDoc[] specifiedPackages();

    Map<String, GroovyClassDoc> getVisibleClasses(List importedClassesAndPackages);
}
